@@ -3,7 +3,7 @@ execnet: pure python lib for connecting to local and remote Python Interpreters.
 
 (c) 2012, Holger Krekel and others
 """
-__version__ = '1.1-ad2'
+__version__ = '1.1.1-ad4'
 
 from . import apipkg
 
@@ -22,11 +22,19 @@ apipkg.initpkg(__name__, {
     'default_group':    '.multi:default_group',
     'dumps':            '.gateway_base:dumps',
     'loads':            '.gateway_base:loads',
+    'load':             '.gateway_base:load',
+    'dump':             '.gateway_base:dump',
     'DataFormatError':  '.gateway_base:DataFormatError',
 })
 
 # CHANGELOG
 #
+# 1.1.1-ad4: Use the newest execnet, includes SSH options
+#
+# 1.1-ad3: Catch more `TypeError` if the connection is closing but the channel attempts
+# to write. We now check is `struct.pack` is not None to proceed.
+# Issue: https://bitbucket.org/hpk42/execnet/issue/22/structpack-can-be-none-sometimes-spits
+#
 # 1.1-ad2: Allow for `sudo python` on local popen gateways
 # Issue: https://bitbucket.org/hpk42/execnet/issue/21/support-sudo-on-local-popen
 #
